@@ -1,5 +1,4 @@
 from .return_class import AbstractApiClass
-from .upload import Upload
 
 
 class DatasetVersion(AbstractApiClass):
@@ -24,10 +23,34 @@ class DatasetVersion(AbstractApiClass):
         return {'dataset_version': self.dataset_version, 'status': self.status, 'dataset_id': self.dataset_id, 'size': self.size, 'row_count': self.row_count, 'created_at': self.created_at, 'error': self.error}
 
     def wait_for_import(self, timeout=900):
+        """
+        A waiting call until dataset version is imported.
+
+        Args:
+            timeout (int, optional): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out. Default value given is 900 milliseconds.
+
+        Returns:
+            None
+        """
         return self.client._poll(self, {'PENDING', 'IMPORTING'}, timeout=timeout)
 
     def wait_for_inspection(self, timeout=None):
+        """
+        A waiting call until dataset version is completely inspected.
+
+        Args:
+            timeout (int, optional): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
+
+        Returns:
+            None
+        """
         return self.client._poll(self, {'PENDING', 'UPLOADING', 'IMPORTING', 'CONVERTING', 'INSPECTING'}, timeout=timeout)
 
     def get_status(self):
+        """
+        Gets the status of the dataset version.
+
+        Returns:
+            Enum (string): A string describing the status of a dataset version (importing, inspecting, complete, etc.).
+        """
         return self.describe().status
