@@ -1,8 +1,8 @@
-from .return_class import AbstractApiClass
-from .feature import Feature
-from concurrent.futures import ThreadPoolExecutor
 import io
-import time
+from concurrent.futures import ThreadPoolExecutor
+
+from .feature import Feature
+from .return_class import AbstractApiClass
 
 
 class FeatureGroupVersion(AbstractApiClass):
@@ -28,30 +28,48 @@ class FeatureGroupVersion(AbstractApiClass):
         return {'feature_group_version': self.feature_group_version, 'sql': self.sql, 'source_tables': self.source_tables, 'created_at': self.created_at, 'status': self.status, 'error': self.error, 'deployable': self.deployable, 'features': self._get_attribute_as_dict(self.features)}
 
     def export_to_file_connector(self, location, export_file_format, overwrite=False):
+        """Export Feature group to File Connector."""
         return self.client.export_feature_group_version_to_file_connector(self.feature_group_version, location, export_file_format, overwrite)
 
     def export_to_database_connector(self, database_connector_id, object_name, write_mode, database_feature_mapping, id_column=None):
+        """Export Feature group to Database Connector."""
         return self.client.export_feature_group_version_to_database_connector(self.feature_group_version, database_connector_id, object_name, write_mode, database_feature_mapping, id_column)
 
     def get_materialization_logs(self, stdout=False, stderr=False):
+        """Returns logs for materialized feature group version."""
         return self.client.get_materialization_logs(self.feature_group_version, stdout, stderr)
 
     def refresh(self):
+        """Calls describe and refreshes the current object's fields"""
         self.__dict__.update(self.describe().__dict__)
         return self
 
     def describe(self):
+        """Get a specific feature group version."""
         return self.client.describe_feature_group_version(self.feature_group_version)
 
     def wait_for_results(self, timeout=3600):
+        """
+        A waiting call until feature group version is created.
+
+        Args:
+            timeout (int, optional): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out. Default value given is 3600 milliseconds.
+
+        Returns:
+            None
+        """
         return self.client._poll(self, {'PENDING'}, timeout=timeout)
 
     def get_status(self):
-        return self.client._call_api('describeFeatureGroupVersion', 'GET', query_params={'featureGroupVersion': self.feature_group_version}, parse_type=FeatureGroupVersion).status
+        """
+        Gets the status of the feature group version.
 
-    def describe(self):
-        return self.client._call_api('describeFeatureGroupVersion', 'GET', query_params={'featureGroupVersion': self.feature_group_version}, parse_type=FeatureGroupVersion)
+        Returns:
+            Enum (string): A string describing the status of a feature group version (pending, complete, etc.).
+        """
+        return self.describe().status
 
+    # internal call
     def _get_avro_file(self, file_part):
         file = io.BytesIO()
         offset = 0
@@ -65,8 +83,17 @@ class FeatureGroupVersion(AbstractApiClass):
         return file
 
     def load_as_pandas(self, max_workers=10):
-        import pandas as pd
+        """
+        Loads the feature group version into a pandas dataframe.
+
+        Args:
+            max_workers (int, optional): The number of threads.
+
+        Returns:
+            DataFrame: A pandas dataframe displaying the data in the feature group version.
+        """
         import fastavro
+        import pandas as pd
 
         file_parts = range(self.client._call_api(
             '_getFeatureGroupVersionPartCount', 'GET', query_params={'featureGroupVersion': self.id}))
