@@ -13,7 +13,7 @@ class FileConnectorInstructions(AbstractApiClass):
         self.auth_options = authOptions
 
     def __repr__(self):
-        return f"FileConnectorInstructions(verified={repr(self.verified)}, write_permission={repr(self.write_permission)}, auth_options={repr(self.auth_options)})"
+        return f"FileConnectorInstructions(verified={repr(self.verified)},\n  write_permission={repr(self.write_permission)},\n  auth_options={repr(self.auth_options)})"
 
     def to_dict(self):
         return {'verified': self.verified, 'write_permission': self.write_permission, 'auth_options': self.auth_options}
