@@ -1,8 +1,9 @@
-from .return_class import AbstractApiClass
-from .model_version import ModelVersion
 import time
-from .refresh_schedule import RefreshSchedule
+
 from .model_location import ModelLocation
+from .model_version import ModelVersion
+from .refresh_schedule import RefreshSchedule
+from .return_class import AbstractApiClass
 
 
 class Model(AbstractApiClass):
@@ -36,40 +37,80 @@ class Model(AbstractApiClass):
         return {'name': self.name, 'model_id': self.model_id, 'model_config': self.model_config, 'created_at': self.created_at, 'project_id': self.project_id, 'shared': self.shared, 'shared_at': self.shared_at, 'train_function_name': self.train_function_name, 'predict_function_name': self.predict_function_name, 'training_input_tables': self.training_input_tables, 'source_code': self.source_code, 'location': self._get_attribute_as_dict(self.location), 'refresh_schedules': self._get_attribute_as_dict(self.refresh_schedules), 'latest_model_version': self._get_attribute_as_dict(self.latest_model_version)}
 
     def refresh(self):
+        """Calls describe and refreshes the current object's fields"""
         self.__dict__.update(self.describe().__dict__)
         return self
 
     def describe(self):
+        """Retrieves a full description of the specified model."""
         return self.client.describe_model(self.model_id)
 
     def rename(self, name):
+        """Renames a model"""
         return self.client.rename_model(self.model_id, name)
 
-    def update_python(self, function_source_code=None, train_function_name=None, predict_function_name=None, training_input_tables=[]):
+    def update_python(self, function_source_code=None, train_function_name=None, predict_function_name=None, training_input_tables=None):
+        """Updates an existing python Model using user provided Python code. If a list of input feature groups are supplied,"""
         return self.client.update_python_model(self.model_id, function_source_code, train_function_name, predict_function_name, training_input_tables)
 
     def set_training_config(self, training_config):
+        """Edits the default model training config"""
         return self.client.set_model_training_config(self.model_id, training_config)
 
+    def set_prediction_params(self, prediction_config):
+        """Sets the model prediction config for the model"""
+        return self.client.set_model_prediction_params(self.model_id, prediction_config)
+
     def get_metrics(self, model_version=None, baseline_metrics=False):
+        """Retrieves a full list of the metrics for the specified model."""
         return self.client.get_model_metrics(self.model_id, model_version, baseline_metrics)
 
     def list_versions(self, limit=100, start_after_version=None):
+        """Retrieves a list of the version for a given model."""
         return self.client.list_model_versions(self.model_id, limit, start_after_version)
 
     def retrain(self, deployment_ids=[]):
+        """Retrains the specified model. Gives you an option to choose the deployments you want the retraining to be deployed to."""
         return self.client.retrain_model(self.model_id, deployment_ids)
 
     def delete(self):
+        """Deletes the specified model and all its versions. Models which are currently used in deployments cannot be deleted."""
         return self.client.delete_model(self.model_id)
 
     def wait_for_training(self, timeout=None):
+        """
+        A waiting call until model is trained.
+
+        Args:
+            timeout (int, optional): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
+
+        Returns:
+            None
+        """
         return self.client._poll(self, {'PENDING', 'TRAINING'}, delay=30, timeout=timeout)
 
     def wait_for_evaluation(self, timeout=None):
+        """
+        A waiting call until model is evaluated completely.
+
+        Args:
+            timeout (int, optional): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
+
+        Returns:
+            None
+        """
         return self.wait_for_training()
 
     def wait_for_full_automl(self, timeout=None):
+        """
+        A waiting call until full AutoML cycle is completed.
+
+        Args:
+            timeout (int, optional): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
+
+        Returns:
+            None
+        """
         start_time = time.time()
         while True:
             if timeout and time.time() - start_time > timeout:
@@ -82,12 +123,33 @@ class Model(AbstractApiClass):
         return self.describe()
 
     def get_status(self, get_automl_status: bool = False):
+        """
+        Gets the status of the model training.
+
+        Returns:
+            Enum (string): A string describing the status of a model training (pending, complete, etc.).
+        """
         if get_automl_status:
             return self.client._call_api('describeModel', 'GET', query_params={'modelId': self.model_id, 'waitForFullAutoml': True}, parse_type=Model).latest_model_version.status
         return self.describe().latest_model_version.status
 
     def create_refresh_policy(self, cron: str):
+        """
+        To create a refresh policy for a model.
+
+        Args:
+            cron (str): A cron style string to set the refresh time.
+
+        Returns:
+            RefreshPolicy: The refresh policy object.
+        """
         return self.client.create_refresh_policy(self.name, cron, 'MODEL', model_ids=[self.id])
 
     def list_refresh_policies(self):
+        """
+        Gets the refresh policies in a list.
+
+        Returns:
+            List<RefreshPolicy>: A list of refresh policy objects.
+        """
         return self.client.list_refresh_policies(model_ids=[self.id])
