@@ -13,7 +13,7 @@ class UseCase(AbstractApiClass):
         self.description = description
 
     def __repr__(self):
-        return f"UseCase(use_case={repr(self.use_case)}, pretty_name={repr(self.pretty_name)}, description={repr(self.description)})"
+        return f"UseCase(use_case={repr(self.use_case)},\n  pretty_name={repr(self.pretty_name)},\n  description={repr(self.description)})"
 
     def to_dict(self):
         return {'use_case': self.use_case, 'pretty_name': self.pretty_name, 'description': self.description}
